==> tmgmt_ec_etranslation-1.0.0.tar.gz: tmgmt_ec_etranslation/src/Plugin/QueueWorker/TranslationQueueWorker.php <==
<?php

namespace Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes incoming translations.
 *
 * @QueueWorker(
 *   id = \Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker\TranslationQueueWorker::ID,
 *   title = @Translation("Processes incoming translations"),
 *   cron = {"time" = 60}
 * )
 */
class TranslationQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  public const ID = 'tmgmt_ec_etranslation_translation';

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * The tmgmt data service.
   *
   * @var \Drupal\tmgmt\Data
   */
  protected $tmgmtData;

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id, $plugin_definition
  ) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    $instance->logger = $container->get('logger.channel.tmgmt_ec_etranslation');
    $instance->tmgmtData = $container->get('tmgmt.data');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    [$jobItemId, $key, $response] = $data;

    $jobItem = $this->entityTypeManager
      ->getStorage('tmgmt_job_item')
      ->load($jobItemId);

    $translatableFields = $this->tmgmtData->filterTranslatable($jobItem->getData());

    if ($this->isHtml($translatableFields[$key]['#text'])) {
      $translation['#text'] = base64_decode($response);
    }
    else {
      $translation['#text'] = $response;
    }

    $this->logger->notice('Translation received for job item @id: @translation', [
      '@id' => $jobItem->id(),
      '@translation' => $translation['#text'],
    ]);

    $jobItem->addTranslatedData($translation, $key);
    $jobItem->addMessage('Translation received: @translation', ['@translation' => $translation['#text']]);
    $jobItem->save();
  }

  /**
   * Checks if the given text is HTML.
   */
  protected function isHtml(string $text): bool {
    return \strip_tags($text) !== $text;
  }

}

==> tmgmt_ec_etranslation-1.1.0.tar.gz: tmgmt_ec_etranslation/src/Plugin/QueueWorker/TranslationQueueWorker.php <==
<?php

declare(strict_types=1);

namespace Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\tmgmt\Data;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes incoming translations.
 *
 * @QueueWorker(
 *   id = \Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker\TranslationQueueWorker::ID,
 *   title = @Translation("Processes incoming translations"),
 *   cron = {"time" = 60}
 * )
 */
class TranslationQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  public const ID = 'tmgmt_ec_etranslation_translation';

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * The logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected LoggerChannelInterface $logger;

  /**
   * The tmgmt data service.
   *
   * @var \Drupal\tmgmt\Data
   */
  protected Data $tmgmtData;

  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    LoggerChannelInterface $logger,
    Data $tmgmtData,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entity_type_manager;
    $this->logger = $logger;
    $this->tmgmtData = $tmgmtData;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition,
  ): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('logger.channel.tmgmt_ec_etranslation'),
      $container->get('tmgmt.data')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    [$jobItemId, $key, $response] = $data;

    $jobItem = $this->entityTypeManager
      ->getStorage('tmgmt_job_item')
      ->load($jobItemId);
    if (!$jobItem) {
      return;
    }

    $translatableFields = $this->tmgmtData->filterTranslatable($jobItem->getData());

    if ($this->isHtml($translatableFields[$key]['#text'])) {
      $translation['#text'] = base64_decode($response);
    }
    else {
      $translation['#text'] = $response;
    }

    $this->logger->notice('Translation received for job item @id: @translation', [
      '@id' => $jobItem->id(),
      '@translation' => $translation['#text'],
    ]);

    $jobItem->addTranslatedData($translation, $key);
    $jobItem->addMessage('Translation received: @translation', ['@translation' => $translation['#text']]);
    $jobItem->save();
  }

  /**
   * Checks if the given text is HTML.
   */
  protected function isHtml(string $text): bool {
    return \strip_tags($text) !== $text;
  }

}
